import _plotly_utils.basevalidators


class LineValidator(_plotly_utils.basevalidators.CompoundValidator):

    def __init__(
        self, plotly_name='line', parent_name='layout.mapbox.layer', **kwargs
    ):
        super(LineValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            data_class_str='Line',
            data_docs="""
            width
                Sets the line width. Has an effect only when
                `type` is set to "line".
""",
            **kwargs
        )



import _plotly_utils.basevalidators


class RangemodeValidator(_plotly_utils.basevalidators.EnumeratedValidator):

    def __init__(
        self, plotly_name='rangemode', parent_name='layout.yaxis', **kwargs
    ):
        super(RangemodeValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type='plot',
            role='info',
            values=['normal', 'tozero', 'nonnegative'],
            **kwargs
        )



import _plotly_utils.basevalidators


class NotchedValidator(_plotly_utils.basevalidators.BooleanValidator):

    def __init__(self, plotly_name='notched', parent_name='box', **kwargs):
        super(NotchedValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type='calc',
            role='style',
            **kwargs
        )



import _plotly_utils.basevalidators


class TextsrcValidator(_plotly_utils.basevalidators.SrcValidator):

    def __init__(self, plotly_name='textsrc', parent_name='violin', **kwargs):
        super(TextsrcValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type='none',
            role='info',
            **kwargs
        )



import _plotly_utils.basevalidators


class StandoffValidator(_plotly_utils.basevalidators.NumberValidator):

    def __init__(
        self,
        plotly_name='standoff',
        parent_name='layout.annotation',
        **kwargs
    ):
        super(StandoffValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type='calc+arraydraw',
            min=0,
            role='style',
            **kwargs
        )
